@@ -7,13 +7,21 @@
 from aiohttp import web
 import asyncio
 
+
 class http_server:
-    def __init__(self, host: str, port: int, loop: asyncio.AbstractEventLoop = None):
+    def __init__(
+            self,
+            host: str,
+            port: int,
+            client_max_size: int = 1024 ** 2,
+            loop: asyncio.AbstractEventLoop = None):
         self.host = host
         self.port = port
         self.loop = loop or asyncio.get_event_loop()
 
-        self.app = web.Application(loop=self.loop)
+        self.app = web.Application(
+            loop=self.loop,
+            client_max_size=client_max_size)
         self.router = self.app.router
         self.add_route = self.app.router.add_route
         self.add_routes = self.app.router.add_routes
